==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleQuickStartTaskFluentImpl<A extends ConsoleQuickStartTaskFluent<A>> extends BaseFluent<A> implements ConsoleQuickStartTaskFluent<A>{
  public ConsoleQuickStartTaskFluentImpl() {
  }
  public ConsoleQuickStartTaskFluentImpl(ConsoleQuickStartTask instance) {
    this.withDescription(instance.getDescription()); 
    this.withReview(instance.getReview()); 
    this.withSummary(instance.getSummary()); 
    this.withTitle(instance.getTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String description;
  private ConsoleQuickStartTaskReviewBuilder review;
  private ConsoleQuickStartTaskSummaryBuilder summary;
  private String title;
  private Map<String,Object> additionalProperties;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * This method has been deprecated, please use method buildReview instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleQuickStartTaskReview getReview() {
    return this.review!=null ?this.review.build():null;
  }
  public ConsoleQuickStartTaskReview buildReview() {
    return this.review!=null ?this.review.build():null;
  }
  public A withReview(ConsoleQuickStartTaskReview review) {
    _visitables.get("review").remove(this.review);
    if (review!=null){ this.review= new ConsoleQuickStartTaskReviewBuilder(review); _visitables.get("review").add(this.review);} else { this.review = null; _visitables.get("review").remove(this.review); } return (A) this;
  }
  public Boolean hasReview() {
    return this.review != null;
  }
  public A withNewReview(String failedTaskHelp,String instructions) {
    return (A)withReview(new ConsoleQuickStartTaskReview(failedTaskHelp, instructions));
  }
  public ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReview() {
    return new ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl();
  }
  public ConsoleQuickStartTaskFluent.ReviewNested<A> withNewReviewLike(ConsoleQuickStartTaskReview item) {
    return new ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl(item);
  }
  public ConsoleQuickStartTaskFluent.ReviewNested<A> editReview() {
    return withNewReviewLike(getReview());
  }
  public ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReview() {
    return withNewReviewLike(getReview() != null ? getReview(): new ConsoleQuickStartTaskReviewBuilder().build());
  }
  public ConsoleQuickStartTaskFluent.ReviewNested<A> editOrNewReviewLike(ConsoleQuickStartTaskReview item) {
    return withNewReviewLike(getReview() != null ? getReview(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSummary instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleQuickStartTaskSummary getSummary() {
    return this.summary!=null ?this.summary.build():null;
  }
  public ConsoleQuickStartTaskSummary buildSummary() {
    return this.summary!=null ?this.summary.build():null;
  }
  public A withSummary(ConsoleQuickStartTaskSummary summary) {
    _visitables.get("summary").remove(this.summary);
    if (summary!=null){ this.summary= new ConsoleQuickStartTaskSummaryBuilder(summary); _visitables.get("summary").add(this.summary);} else { this.summary = null; _visitables.get("summary").remove(this.summary); } return (A) this;
  }
  public Boolean hasSummary() {
    return this.summary != null;
  }
  public A withNewSummary(String failed,String success) {
    return (A)withSummary(new ConsoleQuickStartTaskSummary(failed, success));
  }
  public ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummary() {
    return new ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl();
  }
  public ConsoleQuickStartTaskFluent.SummaryNested<A> withNewSummaryLike(ConsoleQuickStartTaskSummary item) {
    return new ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl(item);
  }
  public ConsoleQuickStartTaskFluent.SummaryNested<A> editSummary() {
    return withNewSummaryLike(getSummary());
  }
  public ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummary() {
    return withNewSummaryLike(getSummary() != null ? getSummary(): new ConsoleQuickStartTaskSummaryBuilder().build());
  }
  public ConsoleQuickStartTaskFluent.SummaryNested<A> editOrNewSummaryLike(ConsoleQuickStartTaskSummary item) {
    return withNewSummaryLike(getSummary() != null ? getSummary(): item);
  }
  public String getTitle() {
    return this.title;
  }
  public A withTitle(String title) {
    this.title=title; return (A) this;
  }
  public Boolean hasTitle() {
    return this.title != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleQuickStartTaskFluentImpl that = (ConsoleQuickStartTaskFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (review != null ? !review.equals(that.review) :that.review != null) return false;
    if (summary != null ? !summary.equals(that.summary) :that.summary != null) return false;
    if (title != null ? !title.equals(that.title) :that.title != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  review,  summary,  title,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (review != null) { sb.append("review:"); sb.append(review + ","); }
    if (summary != null) { sb.append("summary:"); sb.append(summary + ","); }
    if (title != null) { sb.append("title:"); sb.append(title + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ReviewNestedImpl<N> extends ConsoleQuickStartTaskReviewFluentImpl<ConsoleQuickStartTaskFluent.ReviewNested<N>> implements ConsoleQuickStartTaskFluent.ReviewNested<N>,Nested<N>{
    ReviewNestedImpl(ConsoleQuickStartTaskReview item) {
      this.builder = new ConsoleQuickStartTaskReviewBuilder(this, item);
    }
    ReviewNestedImpl() {
      this.builder = new ConsoleQuickStartTaskReviewBuilder(this);
    }
    ConsoleQuickStartTaskReviewBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withReview(builder.build());
    }
    public N endReview() {
      return and();
    }
    
  }
  class SummaryNestedImpl<N> extends ConsoleQuickStartTaskSummaryFluentImpl<ConsoleQuickStartTaskFluent.SummaryNested<N>> implements ConsoleQuickStartTaskFluent.SummaryNested<N>,Nested<N>{
    SummaryNestedImpl(ConsoleQuickStartTaskSummary item) {
      this.builder = new ConsoleQuickStartTaskSummaryBuilder(this, item);
    }
    SummaryNestedImpl() {
      this.builder = new ConsoleQuickStartTaskSummaryBuilder(this);
    }
    ConsoleQuickStartTaskSummaryBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withSummary(builder.build());
    }
    public N endSummary() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleQuickStartTaskFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleQuickStartTaskFluentImpl<A extends ConsoleQuickStartTaskFluent<A>> extends BaseFluent<A> implements ConsoleQuickStartTaskFluent<A>{
  public ConsoleQuickStartTaskFluentImpl() {
  }
  public ConsoleQuickStartTaskFluentImpl(ConsoleQuickStartTask instance) {
    if (instance != null) {
      this.withDescription(instance.getDescription());
      this.withReview(instance.getReview());
      this.withSummary(instance.getSummary());
      this.withTitle(instance.getTitle());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String description;
  private ConsoleQuickStartTaskReviewBuilder review;
  private ConsoleQuickStartTaskSummaryBuilder summary;
  private String title;
  private Map<String,Object> additionalProperties;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  
  /**
   * This method has been deprecated, please use method buildReview instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleQuickStartTaskReview getReview() {
    return this.review!=null ?this.review.build():null;
  }
  public ConsoleQuickStartTaskReview buildReview() {
    return this.review!=null ?this.review.build():null;
  }
  public A withReview(ConsoleQuickStartTaskReview review) {
    _visitables.get("review").remove(this.review);
    if (review!=null){ this.review= new ConsoleQuickStartTaskReviewBuilder(review); _visitables.get("review").add(this.review);} else { this.review = null; _visitables.get("review").remove(this.review); } return (A) this;
  }
  public Boolean hasReview() {
    return this.review != null;
  }
  public A withNewReview(String failedTaskHelp,String instructions) {
    return (A)withReview(new ConsoleQuickStartTaskReview(failedTaskHelp, instructions));
  }
  public ConsoleQuickStartTaskFluentImpl.ReviewNested<A> withNewReview() {
    return new ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl();
  }
  public ConsoleQuickStartTaskFluentImpl.ReviewNested<A> withNewReviewLike(ConsoleQuickStartTaskReview item) {
    return new ConsoleQuickStartTaskFluentImpl.ReviewNestedImpl(item);
  }
  public ConsoleQuickStartTaskFluentImpl.ReviewNested<A> editReview() {
    return withNewReviewLike(getReview());
  }
  public ConsoleQuickStartTaskFluentImpl.ReviewNested<A> editOrNewReview() {
    return withNewReviewLike(getReview() != null ? getReview(): new ConsoleQuickStartTaskReviewBuilder().build());
  }
  public ConsoleQuickStartTaskFluentImpl.ReviewNested<A> editOrNewReviewLike(ConsoleQuickStartTaskReview item) {
    return withNewReviewLike(getReview() != null ? getReview(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSummary instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConsoleQuickStartTaskSummary getSummary() {
    return this.summary!=null ?this.summary.build():null;
  }
  public ConsoleQuickStartTaskSummary buildSummary() {
    return this.summary!=null ?this.summary.build():null;
  }
  public A withSummary(ConsoleQuickStartTaskSummary summary) {
    _visitables.get("summary").remove(this.summary);
    if (summary!=null){ this.summary= new ConsoleQuickStartTaskSummaryBuilder(summary); _visitables.get("summary").add(this.summary);} else { this.summary = null; _visitables.get("summary").remove(this.summary); } return (A) this;
  }
  public Boolean hasSummary() {
    return this.summary != null;
  }
  public A withNewSummary(String failed,String success) {
    return (A)withSummary(new ConsoleQuickStartTaskSummary(failed, success));
  }
  public ConsoleQuickStartTaskFluentImpl.SummaryNested<A> withNewSummary() {
    return new ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl();
  }
  public ConsoleQuickStartTaskFluentImpl.SummaryNested<A> withNewSummaryLike(ConsoleQuickStartTaskSummary item) {
    return new ConsoleQuickStartTaskFluentImpl.SummaryNestedImpl(item);
  }
  public ConsoleQuickStartTaskFluentImpl.SummaryNested<A> editSummary() {
    return withNewSummaryLike(getSummary());
  }
  public ConsoleQuickStartTaskFluentImpl.SummaryNested<A> editOrNewSummary() {
    return withNewSummaryLike(getSummary() != null ? getSummary(): new ConsoleQuickStartTaskSummaryBuilder().build());
  }
  public ConsoleQuickStartTaskFluentImpl.SummaryNested<A> editOrNewSummaryLike(ConsoleQuickStartTaskSummary item) {
    return withNewSummaryLike(getSummary() != null ? getSummary(): item);
  }
  public String getTitle() {
    return this.title;
  }
  public A withTitle(String title) {
    this.title=title; return (A) this;
  }
  public Boolean hasTitle() {
    return this.title != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleQuickStartTaskFluentImpl that = (ConsoleQuickStartTaskFluentImpl) o;
    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(review, that.review)) return false;

    if (!java.util.Objects.equals(summary, that.summary)) return false;

    if (!java.util.Objects.equals(title, that.title)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  review,  summary,  title,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (review != null) { sb.append("review:"); sb.append(review + ","); }
    if (summary != null) { sb.append("summary:"); sb.append(summary + ","); }
    if (title != null) { sb.append("title:"); sb.append(title + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ReviewNestedImpl<N> extends ConsoleQuickStartTaskReviewFluentImpl<ConsoleQuickStartTaskFluentImpl.ReviewNested<N>> implements ConsoleQuickStartTaskFluentImpl.ReviewNested<N>,Nested<N>{
    ReviewNestedImpl(ConsoleQuickStartTaskReview item) {
      this.builder = new ConsoleQuickStartTaskReviewBuilder(this, item);
    }
    ReviewNestedImpl() {
      this.builder = new ConsoleQuickStartTaskReviewBuilder(this);
    }
    ConsoleQuickStartTaskReviewBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withReview(builder.build());
    }
    public N endReview() {
      return and();
    }
    
  }
  class SummaryNestedImpl<N> extends ConsoleQuickStartTaskSummaryFluentImpl<ConsoleQuickStartTaskFluentImpl.SummaryNested<N>> implements ConsoleQuickStartTaskFluentImpl.SummaryNested<N>,Nested<N>{
    SummaryNestedImpl(ConsoleQuickStartTaskSummary item) {
      this.builder = new ConsoleQuickStartTaskSummaryBuilder(this, item);
    }
    SummaryNestedImpl() {
      this.builder = new ConsoleQuickStartTaskSummaryBuilder(this);
    }
    ConsoleQuickStartTaskSummaryBuilder builder;
    public N and() {
      return (N) ConsoleQuickStartTaskFluentImpl.this.withSummary(builder.build());
    }
    public N endSummary() {
      return and();
    }
    
  }
  
}
